seqtools.partition_sequence_once_by_weights_at_least_without_overhang
=====================================================================

.. autofunction:: abjad.tools.seqtools.partition_sequence_once_by_weights_at_least_without_overhang
